@@ -4,6 +4,7 @@ __email__ = "johannes.koester@protonmail.com"
 __license__ = "MIT"
 
 from functools import update_wrapper
+import hashlib
 import inspect
 import uuid
 import os
@@ -54,6 +55,38 @@ def get_uuid(name):
     return uuid.uuid5(UUID_NAMESPACE, name)
 
 
+def get_file_hash(filename, algorithm="sha256"):
+    """find the SHA256 hash string of a file. We use this so that the
+       user can choose to cache working directories in storage.
+    """
+    from snakemake.logging import logger
+
+    # The algorithm must be available
+    try:
+        hasher = hashlib.new(algorithm)
+    except ValueError as ex:
+        logger.error("%s is not an available algorithm." % algorithm)
+        raise ex
+
+    with open(filename, "rb") as f:
+        for chunk in iter(lambda: f.read(4096), b""):
+            hasher.update(chunk)
+    return hasher.hexdigest()
+
+
+def bytesto(bytes, to, bsize=1024):
+    """convert bytes to megabytes.
+       bytes to mb: bytesto(bytes, 'm')
+       bytes to gb: bytesto(bytes, 'g' etc.
+       From https://gist.github.com/shawnbutts/3906915
+    """
+    levels = {"k": 1, "m": 2, "g": 3, "t": 4, "p": 5, "e": 6}
+    answer = float(bytes)
+    for _ in range(levels[to]):
+        answer = answer / bsize
+    return answer
+
+
 class Mode:
     """
     Enum for execution mode of Snakemake.
