@@ -972,11 +972,11 @@ def expand(*args, **wildcards):
 def multiext(prefix, *extensions):
     """Expand a given prefix with multiple extensions (e.g. .txt, .csv, ...)."""
     if any(
-        ("/" in ext or "\\" in ext or not ext.startswith(".")) for ext in extensions
+        (r"/" in ext or r"\\" in ext or not ext.startswith(".")) for ext in extensions
     ):
         raise WorkflowError(
-            "Extensions for multiext may not contain path delimiters "
-            "(/,\) and must start with '.' (e.g. .txt)."
+            r"Extensions for multiext may not contain path delimiters "
+            r"(/,\) and must start with '.' (e.g. .txt)."
         )
     return [flag(prefix + ext, "multiext", flag_value=prefix) for ext in extensions]
 
@@ -1189,6 +1189,12 @@ class Namedlist(list):
         list.__init__(self)
         self._names = dict()
 
+        # white-list of attribute names that can be overridden in _set_name
+        # default to throwing exception if called to prevent use as functions
+        self._allowed_overrides = ["index", "sort"]
+        for name in self._allowed_overrides:
+            setattr(self, name, functools.partial(self._used_attribute, _name=name))
+
         if toclone:
             if custom_map is not None:
                 self.extend(map(custom_map, toclone))
@@ -1205,6 +1211,20 @@ class Namedlist(list):
                 self.append(item)
                 self._add_name(key)
 
+    @staticmethod
+    def _used_attribute(*args, _name, **kwargs):
+        """
+        Generic function that throws an `AttributeError`.
+
+        Used as replacement for functions such as `index()` and `sort()`, 
+        which may be overridden by workflows, to signal to a user that 
+        these functions should not be used.        
+        """
+        raise AttributeError(
+            f"{_name}() cannot be used; attribute name reserved"
+            f" for use in some existing workflows"
+        )
+
     def _add_name(self, name):
         """
         Add a name to the last item.
@@ -1222,10 +1242,10 @@ class Namedlist(list):
         name  -- a name
         index -- the item index
         """
-        if name == "items" or name == "keys" or name == "get":
+        if name not in self._allowed_overrides and hasattr(self.__class__, name):
             raise AttributeError(
-                "invalid name for input, output, wildcard, "
-                "params or log: 'items', 'keys', and 'get' are reserved for internal use"
+                f"invalid name for input, output, wildcard, "
+                f"params or log: {name} is reserved for internal use"
             )
 
         self._names[name] = (index, end)
