@@ -1,7 +1,10 @@
 from snakemake.shell import shell
+
 log = snakemake.log_fmt_shell(append=True)
-shell('''
+shell(
+    """
       cat {snakemake.input} > {snakemake.output}
       (>&2 echo "a stderr message") {log}
       (echo "a stdout message") {log}
-      ''')
+      """
+)
