@@ -1,10 +1,11 @@
 __authors__ = ["Tobias Marschall", "Marcel Martin", "Johannes Köster"]
-__copyright__ = "Copyright 2015-2019, Johannes Köster"
+__copyright__ = "Copyright 2015-2020, Johannes Köster"
 __email__ = "koester@jimmy.harvard.edu"
 __license__ = "MIT"
 
 import os
 import sys
+import uuid
 
 sys.path.insert(0, os.path.dirname(__file__))
 
@@ -325,27 +326,24 @@ def test_issue328():
 
 
 def test_conda():
-    if conda_available():
-        run(dpath("test_conda"), use_conda=True)
+    run(dpath("test_conda"), use_conda=True)
+
+
+def test_upstream_conda():
+    run(dpath("test_conda"), use_conda=True, conda_frontend="conda")
 
 
 def test_conda_custom_prefix():
-    if conda_available():
-        run(
-            dpath("test_conda_custom_prefix"),
-            use_conda=True,
-            conda_prefix="custom",
-            set_pythonpath=False,
-        )
+    run(
+        dpath("test_conda_custom_prefix"),
+        use_conda=True,
+        conda_prefix="custom",
+        set_pythonpath=False,
+    )
 
 
 def test_wrapper():
-    if conda_available():
-        run(dpath("test_wrapper"), use_conda=True)
-
-
-def conda_available():
-    return which("conda")
+    run(dpath("test_wrapper"), use_conda=True)
 
 
 def test_get_log_none():
@@ -629,7 +627,12 @@ def test_singularity_invalid():
 
 @connected
 def test_singularity_conda():
-    run(dpath("test_singularity_conda"), use_singularity=True, use_conda=True)
+    run(
+        dpath("test_singularity_conda"),
+        use_singularity=True,
+        use_conda=True,
+        conda_frontend="conda",
+    )
 
 
 def test_issue612():
@@ -652,91 +655,6 @@ def test_log_input():
     run(dpath("test_log_input"))
 
 
-@pytest.fixture(scope="module")
-def gcloud_cluster():
-    class Cluster:
-        def __init__(self):
-            self.cluster = os.environ["GCLOUD_CLUSTER"]
-            self.bucket_name = "snakemake-testing-{}".format(self.cluster)
-
-            shell(
-                """
-            $GCLOUD container clusters create {self.cluster} --num-nodes 3 --scopes storage-rw --zone us-central1-a --machine-type f1-micro
-            $GCLOUD container clusters get-credentials {self.cluster} --zone us-central1-a
-            $GSUTIL mb gs://{self.bucket_name}
-            """
-            )
-
-        def delete(self):
-            shell(
-                """
-            $GCLOUD container clusters delete {self.cluster} --zone us-central1-a --quiet || true
-            $GSUTIL rm -r gs://{self.bucket_name} || true
-            """
-            )
-
-        def run(self, test="test_kubernetes", **kwargs):
-            try:
-                run(
-                    dpath(test),
-                    kubernetes="default",
-                    default_remote_provider="GS",
-                    default_remote_prefix=self.bucket_name,
-                    no_tmpdir=True,
-                    **kwargs
-                )
-            except Exception as e:
-                shell(
-                    "for p in `kubectl get pods | grep ^snakejob- | cut -f 1 -d ' '`; do kubectl logs $p; done"
-                )
-                raise e
-
-        def reset(self):
-            shell("$GSUTIL rm -r gs://{self.bucket_name}/* || true")
-
-    cluster = Cluster()
-    yield cluster
-    cluster.delete()
-
-
-@gcloud
-@pytest.mark.skip(
-    reason="reenable once we have figured out how to fail if available core hours per month are exceeded"
-)
-@pytest.mark.xfail
-def test_gcloud_plain(gcloud_cluster):
-    gcloud_cluster.reset()
-    gcloud_cluster.run()
-
-
-@gcloud
-@pytest.mark.skip(reason="need a faster cloud compute instance to run this")
-def test_gcloud_conda(gcloud_cluster):
-    gcloud_cluster.reset()
-    gcloud_cluster.run(use_conda=True)
-
-
-@gcloud
-@pytest.mark.skip(reason="need a faster cloud compute instance to run this")
-def test_gcloud_singularity(gcloud_cluster):
-    gcloud_cluster.reset()
-    gcloud_cluster.run(use_singularity=True)
-
-
-@gcloud
-@pytest.mark.skip(reason="need a faster cloud compute instance to run this")
-def test_gcloud_conda_singularity(gcloud_cluster):
-    gcloud_cluster.reset()
-    gcloud_cluster.run(use_singularity=True, use_conda=True)
-
-
-@gcloud()
-@pytest.mark.skip(reason="need a faster cloud compute instance to run this")
-def test_issue1041(gcloud_cluster):
-    gcloud_cluster.reset()
-    gcloud_cluster.run(test="test_issue1041")
-
-
 @connected
 def test_cwl():
     run(dpath("test_cwl"))
